@@ -22,8 +22,22 @@ pub fn read_cards() -> std::io::Result<Vec<Card>> {
 pub fn hw_mons(filter: bool) -> std::io::Result<Vec<HwMon>> {
     Ok(read_cards()?
         .into_iter()
-        .filter_map(|card| hw_mon::open_hw_mon(card).ok())
-        .filter(|hw_mon| !filter || { hw_mon.is_amd() })
-        .filter(|hw_mon| !filter || hw_mon.name_is_amd())
+        .map(|card| {
+            log::info!("opening hw mon for {:?}", card);
+            hw_mon::open_hw_mon(card)
+        })
+        .flatten()
+        .filter(|hw_mon| {
+            !filter || {
+                log::info!("is vendor ok? {}", hw_mon.is_amd());
+                hw_mon.is_amd()
+            }
+        })
+        .filter(|hw_mon| {
+            !filter || {
+                log::info!("is hwmon name ok? {}", hw_mon.name_is_amd());
+                hw_mon.name_is_amd()
+            }
+        })
         .collect())
 }
